
# organelle_segmenter_plugin

::: organelle_segmenter_plugin._dock_widget
::: organelle_segmenter_plugin._reader

::: organelle_segmenter_plugin.core.application
::: organelle_segmenter_plugin.core.controller
::: organelle_segmenter_plugin.core.layer_reader
::: organelle_segmenter_plugin.core.router
::: organelle_segmenter_plugin.core.state
::: organelle_segmenter_plugin.core.view

::: organelle_segmenter_plugin.model.channel
::: organelle_segmenter_plugin.model.segmenter_model

::: organelle_segmenter_plugin.util.directories
::: organelle_segmenter_plugin.util.ui_utils

::: organelle_segmenter_plugin.view.batch_processing_view
::: organelle_segmenter_plugin.view.workflow_select_view
::: organelle_segmenter_plugin.view.workflow_steps_view
